# -*- coding: utf-8 -*-
import sys, re, json
from bs4 import BeautifulSoup
try:
    from urllib2 import urlopen, Request
except ImportError:
    from urllib.request import urlopen, Request
try:
    from urlparse import urljoin
except ImportError:
    from urllib.parse import urljoin
try:
    from urllib import quote
except ImportError:
    from urllib.parse import quote
ua = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.128 Safari/537.36'


def getsoup(url):
    request = Request(url, headers={'User-Agent': ua})
    if (2, 7, 3) <= sys.version_info < (3, 0) or (3, 2) <= sys.version_info < (4, 0):
        return BeautifulSoup(urlopen(request), 'html.parser')
    return BeautifulSoup(urlopen(request), 'html5lib')


def httpget(url):
    request = Request(url, headers={'User-Agent': ua})
    return urlopen(request).read().decode('utf-8')


def category(cat, page=1):
    url = 'https://www.qcvod.net/vodtype/%s-%d/' % (cat, page)
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'qcvod 100', 'error': str(e)}
    ret = []
    for e in soup.select('ul.stui-vodlist li div.stui-vodlist__box'):
        plot = []
        e1 = e.select('div.stui-vodlist__detail h4 a')[0]
        img = e.select('a.stui-vodlist__thumb')[0]['data-original']
        for e2 in e.select('a.stui-vodlist__thumb span'):
            t = e2.text.strip()
            if not t:
                continue
            plot.append(t)
        plot.append(e.select('div.stui-vodlist__detail p.text')[0].text)
        plot = '\n'.join(plot)
        ret.append({'title': e1.text, 'url': urljoin(url, e1['href']), 'img': img, 'plot': plot})
    e = soup.select('span.num')
    if e:
        e = e[0].text.split('/')
        if int(e[0]) < int(e[1]):
            ret.append({'title': 'Next Page (%d)' % (page + 1), 'category': cat, 'page': page + 1})
    return ret


def search(s, page=1):
    url = 'http://www.qcvod.net/vodsearch/%s----------%d---/' % (quote(s), page)
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'qcvod 400', 'error': str(e)}
    ret = []
    for e in soup.select('div.stui-pannel-side'):
        e.extract()
    for e in soup.select('ul.stui-vodlist__media li'):
        plot = []
        e1 = e.select('div.detail a')[0]
        img = e.select('div.thumb a')[0]['data-original']
        for e2 in e.select('div.thumb span'):
            t = e2.text.strip()
            if not t:
                continue
            plot.append(t)
        for e2 in e.select('div.detail span.text-muted'):
            t = e2.text.strip() + e2.next_sibling.strip()
            if not t:
                continue
            plot.append(t)
        plot = '\n'.join(plot)
        ret.append({'title': e1.text, 'url': urljoin(url, e1['href']), 'img': img, 'plot': plot})
    total = soup.select('span.num')
    if total:
        total = int(total[0].text.split('/')[-1])
        if page < total:
            ret.append({'title': 'Next Page (%d/%d)' % (page + 1, total), 'search': s, 'page': page + 1})
    return ret


def vod(url):
    try:
        soup = getsoup(url)
    except Exception as e:
        return {'code': 'qcvod 200', 'error': str(e)}
    ret = []
    for e1 in soup.select('div.playlist'):
        site = e1.select('div.stui-pannel_hd h3')[0].text
        ret1 = []
        for e2 in e1.select('div.stui-pannel_bd li a'):
            ret1.append({e2.text: urljoin(url, e2['href'])})
        ret.append({site: ret1})
    return ret


def play(url):
    try:
        content = httpget(url)
    except Exception as e:
        return {'code': 'qcvod 300', 'error': str(e)}
    s = re.search(r'var player_data=(.*?)</script>', content)
    if not s:
        return {'code': 'qcvod 301'}
    s = s.group(1)
    try:
        data = json.loads(s)
    except Exception as e:
        return {'code': 'qcvod 302', 'error': str(e)}
    return {'title': '', 'url': data['url']}
